@@ -1,6 +1,6 @@
 Lexis <-
 function(entry, exit, duration, entry.status=0, exit.status=0, id, data,
-         merge=TRUE, states )
+         merge=TRUE, states, tol=.Machine$double.eps^0.5)
 {
   nmissing <- missing(entry) + missing(exit) + missing(duration)
   if (nmissing > 2)
@@ -218,7 +218,18 @@ function(entry, exit, duration, entry.status=0, exit.status=0, id, data,
     }
     lex <- cbind(lex, data)
   }
+
+  ## Drop rows with short duration for consistency with splitLexis
+  short.dur <- lex$lex.dur <= tol
+  if (any(short.dur)) {
+      warning("Dropping ", sum(short.dur),
+              " rows with duration of follow up < tol")
+      lex <- subset(lex, !short.dur)
+  }
+
+  ## Return Lexis object
   attr(lex,"time.scales") <- all.time.scales
+  attr(lex,"time.since") <- rep( "", length(all.time.scales) )
   breaks <- vector("list", length(all.time.scales))
   names(breaks) <- all.time.scales
   attr(lex,"breaks") <- breaks
@@ -509,6 +520,7 @@ subset.Lexis <- function(x, ...)
   y <-  subset.data.frame(x, ...)
   attr(y,"breaks") <- attr(x, "breaks")
   attr(y,"time.scales") <- attr(x, "time.scales")
+  attr(y,"time.since") <- attr(x, "time.since")
   return(y)
 }
 
@@ -543,6 +555,7 @@ merge.Lexis <- function(x, y, id, by, ...)
   z <-  base::merge.data.frame(x, y, ...)
   attr(z,"breaks") <- attr(x, "breaks")
   attr(z,"time.scales") <- attr(x, "time.scales")
+  attr(z,"time.since") <- attr(x, "time.since")
   class(z) <- c("Lexis", "data.frame")
   return(z)
 }
@@ -557,7 +570,7 @@ entry <- function(x, time.scale = NULL, by.id = FALSE )
      ave( x[,time.scale[1]], x$lex.id, FUN=if( by.id ) min else I )
     if (length(time.scale) > 1) {
         res <- as.matrix(x[wh, time.scale])
-        if( by.id ) colnames( res ) <- x$lex.id[wh]
+        if( by.id ) rownames( res ) <- x$lex.id[wh]
         return( res )
     }
     else {
@@ -662,3 +675,4 @@ transform.Lexis <- function(`_data`, ... )
     attributes(y) <- save.at
     y
 }
+
